@@ -17,4 +17,7 @@ class HijackRemoteUserMiddleware(object):
         if request.user.is_authenticated():
             username = request.user.get_username()
             if username != remote_username:
-                request.META[self.header] = username
\ No newline at end of file
+                request.META[self.header] = username
+                
+    def authenticate(self, *args, **kwargs):
+        return None
