@@ -4,3 +4,7 @@ DATABASES = {
     'default': {'ENGINE': 'django.db.backends.sqlite3',
                 'NAME': 'test', }
 }
+
+LOCALE_PATHS = (
+    'hijack/locale/',
+)
