@@ -1,18 +1,17 @@
-from django.contrib.admin.views.decorators import staff_member_required
-
+# -*- encoding: utf-8 -*-
 from django.contrib.auth.decorators import login_required
 
 from django.shortcuts import get_object_or_404
-from django.http import HttpResponseBadRequest, HttpResponseRedirect
+from django.http import HttpResponseBadRequest
 
-from hijack.helpers import login_user
+from hijack.decorators import hijack_decorator
+from hijack.helpers import login_user, redirect_to_next
 from hijack.helpers import release_hijack as release_hijack_fx
 
 from compat import get_user_model
-from compat import resolve_url
 
 
-@staff_member_required
+@hijack_decorator
 def login_with_id(request, user_id):
     # input(user_id) is unicode
     try:
@@ -23,13 +22,13 @@ def login_with_id(request, user_id):
     return login_user(request, user)
 
 
-@staff_member_required
+@hijack_decorator
 def login_with_email(request, email):
     user = get_object_or_404(get_user_model(), email=email)
     return login_user(request, user)
 
 
-@staff_member_required
+@hijack_decorator
 def login_with_username(request, username):
     user = get_object_or_404(get_user_model(), username=username)
     return login_user(request, user)
@@ -42,5 +41,5 @@ def release_hijack(request):
 
 @login_required
 def disable_hijack_warning(request):
-    request.session['is_hijacked_user'] = False
-    return HttpResponseRedirect(resolve_url(request.GET.get('next', '/')))
+    request.session['display_hijack_warning'] = False
+    return redirect_to_next(request, default_url='/')
